@@ -7,12 +7,13 @@ import sys
 logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
                     level=logging.DEBUG,
                     stream=sys.stdout)
+import yaml
 # mine
 import hwrt.utils as utils
 
 
 def main(model_folder):
-    recording = sys.stdin.readline()
+    recording = yaml.load(sys.stdin.readline())
     logging.info(recording)
     logging.info("Start evaluation...")
     print(utils.evaluate_model(recording, model_folder))
