@@ -14,12 +14,12 @@ import natsort
 import time
 import datetime
 import subprocess
+import shutil
 # mine
 import preprocess_dataset
 import features
 import create_pfiles
 import create_model
-import get_error
 from HandwrittenData import HandwrittenData
 
 
@@ -328,6 +328,18 @@ def default_model():
     return latest_model
 
 
+def create_adjusted_model_for_percentages(model_src, model_use):
+    """Replace logreg layer by sigmoid to get probabilities."""
+    # Copy model file
+    shutil.copyfile(model_src, model_use)
+    # Adjust model file
+    with open(model_src) as f:
+        content = f.read()
+    content = content.replace("logreg", "sigmoid")
+    with open(model_use, "w") as f:
+        f.write(content)
+
+
 def evaluate_model(recording, model_folder):
     """Evaluate model for a single recording."""
 
@@ -379,8 +391,7 @@ def evaluate_model(recording, model_folder):
         elif "model" in target_folder:
             model_src = get_latest_model(target_folder, "model")
             model_use = "tmp.json"
-            get_error.create_adjusted_model_for_percentages(model_src,
-                                                            model_use)
+            create_adjusted_model_for_percentages(model_src, model_use)
             # Run evaluation
             PROJECT_ROOT = get_project_root()
             time_prefix = time.strftime("%Y-%m-%d-%H-%M")
